@@ -350,7 +350,7 @@ class FingerSvc:
       raise
    def getImage(self, deviceID):
     try:
-      response = self.stub.Scan(finger_pb2_grpc.finger__pb2.GetImageRequest(deviceID=deviceID))
+      response = self.stub.GetImage(finger_pb2_grpc.finger__pb2.GetImageRequest(deviceID=deviceID))
       return response.BMPImage
     except grpc.RpcError as e:
       logger.error(f'Cannot get finger image: {e}')
